Skip to contents

Simulate the effect of gene perturbation on the gene regulatory network. This function propagates the perturbation signal through the GRN to predict changes in gene expression.

Usage

simulate_shift(
  oracle,
  perturb_condition,
  n_propagation = 3,
  GRN_unit = NULL,
  clip_delta_X = FALSE,
  ignore_warning = FALSE
)

Arguments

oracle

Oracle object with fitted GRN

perturb_condition

Named list: gene -> expression value

n_propagation

Number of signal propagation steps (1-5)

GRN_unit

Which GRN to use: "cluster" or "whole"

clip_delta_X

Clip simulated values to original range

ignore_warning

Ignore validation warnings

Value

Modified Oracle object with simulation results